pub struct CipherPartialEditRequest {
pub id: CipherId,
pub folder_id: Option<FolderId>,
pub favorite: bool,
}Expand description
Request to update the subset of cipher fields that a user without edit
permissions is still allowed to change (folder_id and favorite).
Backed by the PUT /ciphers/{id}/partial server endpoint, which authorizes
based on view (not edit) access.
Fields
id: CipherIdfolder_id: Option<FolderId>favorite: boolTrait Implementations
Sourceimpl Clone for CipherPartialEditRequest
impl Clone for CipherPartialEditRequest
Sourcefn clone(&self) -> CipherPartialEditRequest
fn clone(&self) -> CipherPartialEditRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<UT> ConvertError<UT> for CipherPartialEditRequest
impl<UT> ConvertError<UT> for CipherPartialEditRequest
fn try_convert_unexpected_callback_error( e: UnexpectedUniFFICallbackError, ) -> Result<Self>
Sourceimpl Debug for CipherPartialEditRequest
impl Debug for CipherPartialEditRequest
Sourceimpl<'de> Deserialize<'de> for CipherPartialEditRequest
impl<'de> Deserialize<'de> for CipherPartialEditRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<UT> FfiConverter<UT> for CipherPartialEditRequest
impl<UT> FfiConverter<UT> for CipherPartialEditRequest
Sourceconst TYPE_ID_META: MetadataBuffer
const TYPE_ID_META: MetadataBuffer
Type ID metadata, serialized into a [MetadataBuffer].
Sourcetype FfiType = RustBuffer
type FfiType = RustBuffer
The low-level type used for passing values of this type over the FFI. Read more
Sourcefn lower(v: Self) -> RustBuffer
fn lower(v: Self) -> RustBuffer
Lower a rust value of the target type, into an FFI value of type Self::FfiType. Read more
Sourcefn try_lift(buf: RustBuffer) -> Result<Self>
fn try_lift(buf: RustBuffer) -> Result<Self>
Lift a rust value of the target type, from an FFI value of type Self::FfiType. Read more
Sourceimpl From<CipherPartialEditRequest> for JsValuewhere
CipherPartialEditRequest: Serialize,
impl From<CipherPartialEditRequest> for JsValuewhere
CipherPartialEditRequest: Serialize,
Sourcefn from(value: CipherPartialEditRequest) -> Self
fn from(value: CipherPartialEditRequest) -> Self
Converts to this type from the input type.
Sourceimpl FromWasmAbi for CipherPartialEditRequestwhere
Self: DeserializeOwned,
impl FromWasmAbi for CipherPartialEditRequestwhere
Self: DeserializeOwned,
Sourceimpl IntoWasmAbi for &CipherPartialEditRequestwhere
CipherPartialEditRequest: Serialize,
impl IntoWasmAbi for &CipherPartialEditRequestwhere
CipherPartialEditRequest: Serialize,
Sourceimpl IntoWasmAbi for CipherPartialEditRequestwhere
CipherPartialEditRequest: Serialize,
impl IntoWasmAbi for CipherPartialEditRequestwhere
CipherPartialEditRequest: Serialize,
Sourceimpl<UT> Lift<UT> for CipherPartialEditRequest
impl<UT> Lift<UT> for CipherPartialEditRequest
Sourceimpl<UT> LiftRef<UT> for CipherPartialEditRequest
impl<UT> LiftRef<UT> for CipherPartialEditRequest
Sourceimpl<UT> LiftReturn<UT> for CipherPartialEditRequest
impl<UT> LiftReturn<UT> for CipherPartialEditRequest
Sourcetype ReturnType = <CipherPartialEditRequest as Lift<UT>>::FfiType
type ReturnType = <CipherPartialEditRequest as Lift<UT>>::FfiType
FFI return type for trait interfaces
Sourcefn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
fn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
Lift a successfully returned value from a trait interface
fn lift_foreign_return(
ffi_return: Self::ReturnType,
call_status: RustCallStatus,
) -> Self
fn lift_foreign_return( ffi_return: Self::ReturnType, call_status: RustCallStatus, ) -> Self
Lift a foreign returned value from a trait interface Read more
fn lift_error(_buf: RustBuffer) -> Self
fn lift_error(_buf: RustBuffer) -> Self
Lift a Rust value for a callback interface method error result Read more
fn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
fn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
Lift a Rust value for an unexpected callback interface error Read more
Sourceimpl<UT> Lower<UT> for CipherPartialEditRequest
impl<UT> Lower<UT> for CipherPartialEditRequest
Sourceimpl<UT> LowerError<UT> for CipherPartialEditRequest
impl<UT> LowerError<UT> for CipherPartialEditRequest
Sourcefn lower_error(obj: Self) -> RustBuffer
fn lower_error(obj: Self) -> RustBuffer
Lower this value for scaffolding function return Read more
Sourceimpl<UT> LowerReturn<UT> for CipherPartialEditRequest
impl<UT> LowerReturn<UT> for CipherPartialEditRequest
Sourcetype ReturnType = <CipherPartialEditRequest as Lower<UT>>::FfiType
type ReturnType = <CipherPartialEditRequest as Lower<UT>>::FfiType
The type that should be returned by scaffolding functions for this type. Read more
Sourcefn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
fn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
Lower the return value from an scaffolding call Read more
fn handle_failed_lift(
error: LiftArgsError,
) -> Result<Self::ReturnType, RustCallError>
fn handle_failed_lift( error: LiftArgsError, ) -> Result<Self::ReturnType, RustCallError>
Lower the return value for failed argument lifts Read more
Sourceimpl OptionFromWasmAbi for CipherPartialEditRequestwhere
Self: DeserializeOwned,
impl OptionFromWasmAbi for CipherPartialEditRequestwhere
Self: DeserializeOwned,
Sourceimpl OptionIntoWasmAbi for CipherPartialEditRequestwhere
CipherPartialEditRequest: Serialize,
impl OptionIntoWasmAbi for CipherPartialEditRequestwhere
CipherPartialEditRequest: Serialize,
Sourceimpl RefFromWasmAbi for CipherPartialEditRequestwhere
Self: DeserializeOwned,
impl RefFromWasmAbi for CipherPartialEditRequestwhere
Self: DeserializeOwned,
Sourcetype Abi = <JsType as RefFromWasmAbi>::Abi
type Abi = <JsType as RefFromWasmAbi>::Abi
The Wasm ABI type references to
Self are recovered from.Sourcetype Anchor = SelfOwner<CipherPartialEditRequest>
type Anchor = SelfOwner<CipherPartialEditRequest>
The type that holds the reference to
Self for the duration of the
invocation of the function that has an &Self parameter. This is
required to ensure that the lifetimes don’t persist beyond one function
call, and so that they remain anonymous.Sourceimpl Serialize for CipherPartialEditRequest
impl Serialize for CipherPartialEditRequest
Sourceimpl Tsify for CipherPartialEditRequest
impl Tsify for CipherPartialEditRequest
const DECL: &'static str = "/**\n * Request to update the subset of cipher fields that a user without edit\n * permissions is still allowed to change (`folder_id` and `favorite`).\n *\n * Backed by the `PUT /ciphers/{id}/partial` server endpoint, which authorizes\n * based on view (not edit) access.\n */\nexport interface CipherPartialEditRequest {\n id: CipherId;\n folderId: FolderId | undefined;\n favorite: boolean;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
Sourceimpl<UT> TypeId<UT> for CipherPartialEditRequest
impl<UT> TypeId<UT> for CipherPartialEditRequest
const TYPE_ID_META: MetadataBuffer
Sourceimpl VectorFromWasmAbi for CipherPartialEditRequestwhere
Self: DeserializeOwned,
impl VectorFromWasmAbi for CipherPartialEditRequestwhere
Self: DeserializeOwned,
type Abi = <JsType as VectorFromWasmAbi>::Abi
unsafe fn vector_from_abi(js: Self::Abi) -> Box<[Self]>
Sourceimpl VectorIntoWasmAbi for CipherPartialEditRequestwhere
CipherPartialEditRequest: Serialize,
impl VectorIntoWasmAbi for CipherPartialEditRequestwhere
CipherPartialEditRequest: Serialize,
type Abi = <JsType as VectorIntoWasmAbi>::Abi
fn vector_into_abi(vector: Box<[Self]>) -> Self::Abi